.. |date| date::

.. |v9| image:: https://img.shields.io/badge/python-3.9-blue.svg
   :alt: Python 3.9

.. |v10| image:: https://img.shields.io/badge/python-3.10-blue.svg
   :alt: Python 3.10

.. |v11| image:: https://img.shields.io/badge/python-3.11-blue.svg
   :alt: Python 3.11

|v9| |v10| |v11|

******************
Welcome to Yangson
******************

:Author: Ladislav Lhotka <ladislav@lhotka.name>
:Date: |date|

*Yangson* is a Python 3 library for working with configuration and
state data modelled using the YANG_ data modelling language.

Installation
============

::

    python -m pip install yangson

Note that *Yangson* requires Python 3.9 or higher.

Development
===========

* Instructions_ for installing the development environment.

Links
=====

* `Git repository`_
* `Documentation`_

.. _YANG: https://tools.ietf.org/html/rfc7950
.. _Instructions: https://github.com/CZ-NIC/yangson/wiki/devinstall
.. _Git repository: https://github.com/CZ-NIC/yangson
.. _Documentation: https://yangson.labs.nic.cz
